@@ -1,15 +1,13 @@
-#!/usr/bin/env python
-# coding: utf-8
 
 # # RSA Encryption
 
 # In this document, we talk about the neccessary tools to perform RSA encryption.  Below we have the functions PadMessage and DepadMessage, we are thoroughly commented if you wish to read over how these functions work.  What these functions do is turn our String message into a list of numbers, each of which is no bigger than our pulic modulus.  Once again, If you have not done so, I would highly recommend watching Dr. Misseldine's [RSA Encryption](https://www.youtube.com/watch?v=LcKquwXkhzU&list=PLz7t89zv8Lp2D6xQOG7kUEbN1KP5u-mpH&index=79) video, he explains the math behind RSA encryption, and this code was adapted from his program written in MAGMA.  
 
 # In[ ]:
+import math
 
 
-
-def PadMessage(message: str, N: int):
+def PadMessage(message: str, N):
     # create the array that we will use to save our list of numbers
     PW = []
     # create a new string that we will add on to to create each number
@@ -232,7 +230,6 @@ def DepadMessage(digits):
     return plaintext
 
 
-# Here is where the magic happens, we define the ExpRSA function, as well as the EncryptRSA and DecryptRSA functions that we will use to encrypt and decrypt messages using the RSA cryptosystem.  The code is commented below.  
 
 
 def to_binary(b: int):
@@ -249,7 +246,7 @@ def to_binary(b: int):
         # while the quotient is nonzero...
         while q!=0:
             # find the quotient of b/2
-            q = floor(b/2)
+            q = math.floor(b/2)
             # as well as the remainder
             r = b % 2
             # take the remainder to be the digit of b in
@@ -275,7 +272,7 @@ def bin_exp(a: int, b: int, n: int):
         q = 1
         # compute b in binary and save the result in reverse in binary list
         while q!=0:
-            q = floor(b/2)
+            q = math.floor(b/2)
             r = b % 2
             binary.append(r)
             b = q
